#include <avr/io.h>

#include "atm8_uart.h"
#include "stdlib.h"
#include "Typedefs.h"
#include "avr/interrupt.h"
#include <util/setbaud.h>


	
bool8 UART_bInit(uchar16 ucBaudrate, bool8 bIntEnabled){

	DDRD |= (1<<PD1);		//Tx Out
	DDRD &= ~(1<<PD0);		//Rx In
	PORTD |= (1<<PD0);		//activate Pullup
	UBRRH = UBRRH_VALUE;	//Set baud rate
	UBRRL = UBRRL_VALUE;		
	UCSRB = (1<<RXEN)|(1<<TXEN);		//Enable receiver and transmitter
	if (bIntEnabled==TRUE){
		UCSRB |= (1<<RXCIE)|(1<<TXCIE);
		sei();
	} else if (bIntEnabled!=FALSE){		//bIntEnabled ungltig, d.h. weder TRUE noch FALSE
		return FALSE;			
	}
	UCSRC = (1<<URSEL)|(1<<UCSZ1)|(1<<UCSZ0);	//Set frame format: 8data, 1 Stop bit

	return TRUE;
}

char UART_cReceive(void){
	while (!(UCSRA & (1<<RXC)));  //Wait for data to be received
	return UDR;
}

void UART_vTransmit(uchar8 ucChardata){
	while(!( UCSRA & (1<<UDRE)));	// Wait for empty transmit buffer
	UDR = ucChardata;					// Put data into buffer, sends the data
}

void UART_vPuts(char *cChardata){
	while (*cChardata) {   // solange != '\0' also ungleich dem "String-Endezeichen(Terminator)"
		UART_vTransmit(*cChardata);
		cChardata++;
	}
}

void UART_vPuti(uchar16 ucNumber){
	char cCharBuffer[7];
	itoa( ucNumber, cCharBuffer, 10 ); // 10 fuer radix -> Dezimalsystem
	UART_vPuts(cCharBuffer);
}

void UART_vNewLine(uchar8 ucNumber){
	uchar8 ucI;
	for (ucI=0;ucI<ucNumber;ucI++){
		UART_vPuts("\r\n");	
	}
	
}
